#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-DeYtsrKQlkOBQLbQvZtKdd
key:                  ghcide-2.3.0.0-DeYtsrKQlkOBQLbQvZtKdd
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  0906f2c2a562e170276faa9a09f391de
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-DeYtsrKQlkOBQLbQvZtKdd
depends:
    Diff-0.5-2C7w3Xpas4N2eLiJ3AY0s2 Glob-0.10.2-Avf8cPkZvKuBKXuRXXUc0w
    aeson-2.2.2.0-5ic0qdnYZHH6zFYkxFCOtx array-0.5.6.0
    async-2.2.6-AoIAnpP1AE52EgJKBLwe0w base-4.18.2.1
    base16-bytestring-1.0.2.0-62KyUBG4ZgmGpNMNR9lueV binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-BUUMd5L4HIgpuJP9IYz4Q
    co-log-core-0.3.2.6-BqaVaP3BOs01hK419oQgq containers-0.6.7
    cryptohash-sha1-0.11.101.0-CS2R1q6F1RR95pO7btSbPN
    data-default-0.7.1.3-GWfmROYPtdX1tMV8eki8U8 deepseq-1.4.8.1
    dependent-map-0.4.0.1-KJMzDrFzu9o3w9RNN5Cr7P
    dependent-sum-0.7.2.0-DMsK6Di5Qco19qzXQUo9uI directory-1.3.8.5
    dlist-1.0-Lh7RKSnSGOY3vBCcbQnr6G
    enummapset-0.7.3.0-JznCcsmueTsBhzTcFmplcI exceptions-0.10.7
    extra-1.7.16-53b454gmz0kFA1gZEklCYN filepath-1.4.300.1
    fingertree-0.1.6.3-F7juADIifXRFDTfdV28ftU
    focus-1.0.3.2-GKGgBlyAjlN6ExS1DXwJCU ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-57Zaj3RfiJLAo88snE4YPk
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-4FNWWqmxixO5EYvBMDxZnw
    hashable-1.4.7.0-GIhdlNoQDSBAO6SjAK3pjT
    hie-bios-0.12.0-J2hOTualjbFHBpAFpO56cT
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-2wMGUArMXMt7VVlKdNyo33
    hls-graph-2.3.0.0-L6iIZ7m7w1YJa2Z6meY774
    hls-plugin-api-2.3.0.0-Lpx2Nh226V079b3MemSa0j
    implicit-hie-0.1.4.0-EczINajPxLBH9GpRd45rvq
    implicit-hie-cradle-0.5.0.1-3yfEYtVSJBh9u5PMtPgyuf
    lens-5.3.4-7EFHuOJ8RipEfJSuyvyaT1
    list-t-1.0.5.7-8uyjtbkWKjT5qMI8gze7Tb
    lsp-2.2.0.0-8mf8q1mXbd2HMf20ri37xs
    lsp-types-2.0.2.0-7od6wfuIoHdC81PFEfihe5 mtl-2.3.1
    opentelemetry-0.8.0-DTk1t3YACJeCFfCAKTbIZp
    optparse-applicative-0.18.1.0-7SnpJ8KlnMr6TDIti6V1EO
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-C1cv8XSZ4iy3B6vMI1FDsE
    prettyprinter-ansi-terminal-1.1.4-CNlRFZ2GpdRBzmk8mIoYTm
    random-1.2.1.3-DsZJWYr04hc2YE8pqhZcvw
    regex-tdfa-1.3.2.5-5LmFHIFwXRgGzMBvrwvbhl
    row-types-1.0.1.2-C0qv73e4TzQJfAFBPR4bwl
    safe-exceptions-0.1.7.4-DmOZftB7Yx22eMai0NBHs8
    sorted-list-0.2.3.1-BRDJb5x8zUgGNP8vOH4diJ
    sqlite-simple-0.4.19.0-KPPYcErymMCAAt2BGjb0sV stm-2.5.1.0
    stm-containers-1.2.1.1-El57AsovErUdbRat0eDF4
    syb-0.7.3-G9hX5jRi7mOEE2JrTy5wGt text-2.0.2
    text-rope-0.3-A6VkYIOkEx3PIWIM3KJ5A time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-8PFdViM4kSw68msSMSHlHp
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-1VPUCssH1vYLkUFtdr2cZd
    vector-0.13.2.0-DH6UT7zpR061zYDIVIbmaS

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

